import { Component } from "./component";
/**
 * Invalidator Subscription.
 *
 * @final
 */
export declare class InvalidatorSubscription {
    _flags: number;
    invalidator: Invalidator;
    private _component;
    private _callback;
    _invalidatorPrev: InvalidatorSubscription | null;
    _invalidatorNext: InvalidatorSubscription | null;
    _componentPrev: InvalidatorSubscription | null;
    _componentNext: InvalidatorSubscription | null;
    private _isCanceled;
    constructor(flags: number, invalidator: Invalidator, component: Component<any, any> | null, callback: Function | null);
    _cancel(): void;
    /**
     * Cancel subscription.
     */
    cancel(): void;
    _invalidate(): void;
}
/**
 * Invalidator object is a low level object for implementing reactive bindings.
 *
 * @final
 */
export declare class Invalidator {
    /**
     * Updates each time when invalidator is invalidated, uses scheduler
     * monotonically increasing clock.
     */
    mtime: number;
    _subscriptions: InvalidatorSubscription | null;
    _transientSubscriptions: InvalidatorSubscription | null;
    constructor();
    /**
     * Create a subscription with a callback handler.
     */
    subscribe(callback: Function): InvalidatorSubscription;
    /**
     * Create a transient subscription with a callback handler.
     */
    transientSubscribe(callback: Function): InvalidatorSubscription;
    /**
     * Create a subscription that will invalidate component.
     */
    subscribeComponent(component: Component<any, any>): InvalidatorSubscription;
    /**
     * Create a transient subscription that will invalidate component.
     */
    transientSubscribeComponent(component: Component<any, any>): InvalidatorSubscription;
    /**
     * Returns true if invalidator object has subscriptions.
     */
    hasSubscriptions(): boolean;
    /**
     * Invalidate all subscriptions.
     */
    invalidate(): void;
}
