export declare const SvgNamespace: string;
export declare const XlinkNamespace: string;
export declare const XmlNamespace: string;
declare global  {
    interface Element {
        closest(selector: string): Element | null;
    }
}
/**
 * Selector function should return true if element matches this selector.
 */
export declare type SelectorFn = (element: Element) => boolean;
/**
 * VModel flags.
 */
export declare const enum VModelFlags {
    EnabledCloning = 1,
    Svg = 32768,
}
/**
 * VNode flags.
 */
export declare const enum VNodeFlags {
    Text = 1,
    Element = 2,
    Component = 4,
    Root = 8,
    TrackByKeyChildren = 16,
    DynamicShapeAttrs = 32,
    TextInputElement = 64,
    CheckedInputElement = 128,
    InputElement = 192,
    KeepAlive = 256,
    BindOnce = 512,
    ImmutableProps = 1024,
    UnsafeHTML = 2048,
    Svg = 32768,
    VModel = 131072,
    VModelUpdateHandler = 262144,
}
/**
 * VNode flags used when DEBUG mode is enabled.
 */
export declare const enum VNodeDebugFlags {
    Rendered = 1,
    Mounted = 2,
    Attached = 4,
    Detached = 8,
    Disposed = 16,
    DisabledChildrenShapeError = 32,
    DisabledFreeze = 64,
}
/**
 * ComponentDescriptor flags.
 */
export declare const enum ComponentDescriptorFlags {
    EnabledBackRef = 1,
    Svg = 32768,
    Canvas2D = 65536,
    VModel = 131072,
    EnabledRecycling = 524288,
}
/**
 * Component flags.
 */
export declare const enum ComponentFlags {
    Disposed = 1,
    Attached = 2,
    Dirty = 4,
    DirtyView = 8,
    UpdateEachFrame = 16,
    InUpdateEachFrameQueue = 32,
    Recycled = 64,
    InUpdateQueue = 128,
    HighPriorityUpdate = 256,
    EnabledThrottling = 512,
    ImmutableProps = 1024,
    Svg = 32768,
    Canvas2D = 65536,
    VModel = 131072,
    EnabledRecycling = 524288,
}
/**
 * Set HTML attribute.
 */
export declare function setAttr(node: Element, key: string, value: string): void;
/**
 * This function doesn't do anything, it just returns the same `tagName` value.
 *
 * It is used so that when building application in production mode, we can replace all occurences of `getTagName`
 * function and minify all tag names.
 */
export declare function getTagName(tagName: string): string;
/**
 * This function doesn't do anything, it just returns the same `className` value.
 *
 * It is used so that when building application in production mode, we can replace all occurences of `getClassName`
 * function and minify all class names.
 */
export declare function getClassName(className: string): string;
export declare function matchesWithAncestors(element: Element, selector: string | SelectorFn, sentinel?: Element | null): Element | null;
export {};
